@@ -1,34 +1,42 @@
+import logging
+import sys
 import uuid
 
 import flask
 import structlog
 
-from .some_module import some_function
+from some_module import some_function
 
 
 logger = structlog.get_logger()
 app = flask.Flask(__name__)
 
 
-@app.route('/login', methods=['POST', 'GET'])
+@app.route("/login", methods=["POST", "GET"])
 def some_route():
     log = logger.new(
         request_id=str(uuid.uuid4()),
     )
     # do something
     # ...
-    log.info('user logged in', user='test-user')
+    log.info("user logged in", user="test-user")
     # gives you:
     # event='user logged in' request_id='ffcdc44f-b952-4b5f-95e6-0f1f3a9ee5fd' user='test-user'
     # ...
     some_function()
     # ...
+    return "logged in!"
 
 if __name__ == "__main__":
+    logging.basicConfig(
+        format="%(message)s",
+        stream=sys.stdout,
+        level=logging.INFO,
+    )
     structlog.configure(
         processors=[
             structlog.processors.KeyValueRenderer(
-                key_order=['event', 'request_id'],
+                key_order=["event", "request_id"],
             ),
         ],
         context_class=structlog.threadlocal.wrap_dict(dict),
