@@ -7,15 +7,15 @@ class ConditionalDropper(object):
 
     def __call__(self, logger, method_name, event_dict):
         """
-        >>> cd = ConditionalDropper('127.0.0.1')
-        >>> cd(None, None, {'event': 'foo', 'peer': '10.0.0.1'})
+        >>> cd = ConditionalDropper("127.0.0.1")
+        >>> cd(None, None, {"event": "foo", "peer": "10.0.0.1"})
         {'peer': '10.0.0.1', 'event': 'foo'}
-        >>> cd(None, None, {'event': 'foo', 'peer': '127.0.0.1'})
+        >>> cd(None, None, {"event": "foo", "peer": "127.0.0.1"})
         Traceback (most recent call last):
         ...
         DropEvent
         """
-        if event_dict.get('peer') == self._peer_to_ignore:
+        if event_dict.get("peer") == self._peer_to_ignore:
             raise DropEvent
         else:
             return event_dict
