@@ -10,6 +10,7 @@ from __future__ import absolute_import, division, print_function
 
 from six import StringIO
 
+
 try:
     import colorama
 except ImportError:
@@ -23,8 +24,6 @@ __all__ = [
 
 _MISSING = (
     "{who} requires the {package} package installed.  "
-    "If you want to use the helpers from structlog.dev, it is strongly "
-    "recommended to install structlog using `pip install structlog[dev]`."
 )
 _EVENT_WIDTH = 30  # pad the event name to so many characters
 
@@ -99,11 +98,18 @@ class ConsoleRenderer(object):
 
     :param int pad_event: Pad the event to this many characters.
     :param bool colors: Use colors for a nicer output.
+    :param bool force_colors: Force colors even for non-tty destinations.
+        Use this option if your logs are stored in a file that is meant
+        to be streamed to the console.
     :param bool repr_native_str: When ``True``, :func:`repr()` is also applied
         to native strings (i.e. unicode on Python 3 and bytes on Python 2).
         Setting this to ``False`` is useful if you want to have human-readable
         non-ASCII output on Python 2.  The `event` key is *never*
         :func:`repr()` -ed.
+    :param dict level_styles: When present, use these styles for colors. This
+        must be a dict from level names (strings) to colorama styles. The
+        default can be obtained by calling
+        :meth:`ConsoleRenderer.get_default_level_styles`
 
     Requires the colorama_ package if *colors* is ``True``.
 
@@ -112,9 +118,11 @@ class ConsoleRenderer(object):
     .. versionadded:: 16.0
     .. versionadded:: 16.1 *colors*
     .. versionadded:: 17.1 *repr_native_str*
+    .. versionadded:: 18.1 *force_colors*
+    .. versionadded:: 18.1 *level_styles*
     """
     def __init__(self, pad_event=_EVENT_WIDTH, colors=True,
-                 repr_native_str=False):
+                 force_colors=False, repr_native_str=False, level_styles=None):
         if colors is True:
             if colorama is None:
                 raise SystemError(
@@ -124,23 +132,23 @@ class ConsoleRenderer(object):
                     )
                 )
 
-            colorama.init()
+            if force_colors:
+                colorama.deinit()
+                colorama.init(strip=False)
+            else:
+                colorama.init()
+
             styles = _ColorfulStyles
         else:
             styles = _PlainStyles
 
         self._styles = styles
         self._pad_event = pad_event
-        self._level_to_color = {
-            "critical": styles.level_critical,
-            "exception": styles.level_exception,
-            "error": styles.level_error,
-            "warn": styles.level_warn,
-            "warning": styles.level_warn,
-            "info": styles.level_info,
-            "debug": styles.level_debug,
-            "notset": styles.level_notset,
-        }
+
+        if level_styles is None:
+            self._level_to_color = self.get_default_level_styles(colors)
+        else:
+            self._level_to_color = level_styles
 
         for key in self._level_to_color.keys():
             self._level_to_color[key] += styles.bright
@@ -168,7 +176,7 @@ class ConsoleRenderer(object):
                 # can be a number if timestamp is UNIXy
                 self._styles.timestamp + str(ts) + self._styles.reset + " "
             )
-        level = event_dict.pop("level",  None)
+        level = event_dict.pop("level", None)
         if level is not None:
             sio.write(
                 "[" + self._level_to_color[level] +
@@ -211,3 +219,35 @@ class ConsoleRenderer(object):
             sio.write("\n" + exc)
 
         return sio.getvalue()
+
+    @staticmethod
+    def get_default_level_styles(colors=True):
+        """
+        Get the default styles for log levels
+
+        This is intended to be used with :class:`ConsoleRenderer`'s
+        ``level_styles`` parameter.  For example, if you are adding
+        custom levels in your home-grown
+        :func:`~structlog.stdlib.add_log_level` you could do::
+
+            my_styles = ConsoleRenderer.get_default_level_styles()
+            my_styles["EVERYTHING_IS_ON_FIRE"] = my_styles["critical"]
+            renderer = ConsoleRenderer(level_styles=my_styles)
+
+        :param bool colors: Whether to use colorful styles. This must match the
+            `colors` parameter to :class:`ConsoleRenderer`. Default: True.
+        """
+        if colors:
+            styles = _ColorfulStyles
+        else:
+            styles = _PlainStyles
+        return {
+            "critical": styles.level_critical,
+            "exception": styles.level_exception,
+            "error": styles.level_error,
+            "warn": styles.level_warn,
+            "warning": styles.level_warn,
+            "info": styles.level_info,
+            "debug": styles.level_debug,
+            "notset": styles.level_notset,
+        }
