@@ -20,16 +20,19 @@ def build_bl(logger=None, processors=None, context=None):
     Convenience function to build BoundLoggerBases with sane defaults.
     """
     return BoundLoggerBase(
-        logger or ReturnLogger(),
-        processors or _CONFIG.default_processors,
+        logger if logger is not None else ReturnLogger(),
+        processors if processors is not None else _CONFIG.default_processors,
         context if context is not None else _CONFIG.default_context_class(),
     )
 
 
 class TestBinding(object):
     def test_repr(self):
-        l = build_bl(processors=[1, 2, 3], context={})
-        assert '<BoundLoggerBase(context={}, processors=[1, 2, 3])>' == repr(l)
+        bl = build_bl(processors=[1, 2, 3], context={})
+
+        assert (
+            "<BoundLoggerBase(context={}, processors=[1, 2, 3])>"
+        ) == repr(bl)
 
     def test_binds_independently(self):
         """
@@ -75,6 +78,17 @@ class TestBinding(object):
 
 
 class TestProcessing(object):
+    def test_event_empty_string(self):
+        """
+        Empty strings are a valid event.
+        """
+        b = build_bl(processors=[], context={})
+
+        args, kw = b._process_event("meth", "", {"foo": "bar"})
+
+        assert () == args
+        assert {"event": "", "foo": "bar"} == kw
+
     def test_copies_context_before_processing(self):
         """
         BoundLoggerBase._process_event() gets called before relaying events
