@@ -4,26 +4,24 @@
 
 from __future__ import absolute_import, division, print_function
 
+import platform
+import sys
 import warnings
 
+from collections import OrderedDict
+
 import pytest
 
-from pretend import call_recorder, call, stub
+from pretend import call, call_recorder, stub
 from six import PY3
 
+import structlog
+
 from structlog._base import BoundLoggerBase
 from structlog._config import (
-    BoundLoggerLazyProxy,
-    _CONFIG,
-    _BUILTIN_DEFAULT_CONTEXT_CLASS,
-    _BUILTIN_DEFAULT_PROCESSORS,
-    _BUILTIN_DEFAULT_LOGGER_FACTORY,
-    _BUILTIN_DEFAULT_WRAPPER_CLASS,
-    configure,
-    configure_once,
-    get_logger,
-    reset_defaults,
-    wrap_logger,
+    _BUILTIN_DEFAULT_CONTEXT_CLASS, _BUILTIN_DEFAULT_LOGGER_FACTORY,
+    _BUILTIN_DEFAULT_PROCESSORS, _BUILTIN_DEFAULT_WRAPPER_CLASS, _CONFIG,
+    BoundLoggerLazyProxy, configure, configure_once, get_logger, wrap_logger
 )
 
 
@@ -41,22 +39,56 @@ class Wrapper(BoundLoggerBase):
     """
 
 
+def test_default_context_class():
+    """
+    Default context class is dict on Python 3.6+ and PyPy, OrderedDict
+    otherwise.
+    """
+    if (
+        platform.python_implementation() == "PyPy" or
+        sys.version_info[:2] >= (3, 6)
+    ):
+        cls = dict
+    else:
+        cls = OrderedDict
+
+    assert cls is _BUILTIN_DEFAULT_CONTEXT_CLASS
+
+
 class TestConfigure(object):
     def teardown_method(self, method):
-        reset_defaults()
+        structlog.reset_defaults()
+
+    def test_get_config_is_configured(self):
+        """
+        Return value of structlog.get_config() works as input for
+        structlog.configure(). is_configured() reflects the state of
+        configuration.
+        """
+        assert False is structlog.is_configured()
+
+        structlog.configure(**structlog.get_config())
+
+        assert True is structlog.is_configured()
+
+        structlog.reset_defaults()
+
+        assert False is structlog.is_configured()
 
     def test_configure_all(self, proxy):
         x = stub()
         configure(processors=[x], context_class=dict)
         b = proxy.bind()
+
         assert [x] == b._processors
         assert dict is b._context.__class__
 
     def test_reset(self, proxy):
         x = stub()
         configure(processors=[x], context_class=dict, wrapper_class=Wrapper)
-        reset_defaults()
+        structlog.reset_defaults()
         b = proxy.bind()
+
         assert [x] != b._processors
         assert _BUILTIN_DEFAULT_PROCESSORS == b._processors
         assert isinstance(b, _BUILTIN_DEFAULT_WRAPPER_CLASS)
@@ -82,11 +114,6 @@ class TestConfigure(object):
         configure()
         assert True is _CONFIG.is_configured
 
-    def test_rest_resets_is_configured(self):
-        configure()
-        reset_defaults()
-        assert False is _CONFIG.is_configured
-
     def test_configures_logger_factory(self):
         def f():
             pass
@@ -97,7 +124,7 @@ class TestConfigure(object):
 
 class TestBoundLoggerLazyProxy(object):
     def teardown_method(self, method):
-        reset_defaults()
+        structlog.reset_defaults()
 
     def test_repr(self):
         p = BoundLoggerLazyProxy(
@@ -247,7 +274,7 @@ class TestBoundLoggerLazyProxy(object):
 
 class TestFunctions(object):
     def teardown_method(self, method):
-        reset_defaults()
+        structlog.reset_defaults()
 
     def test_wrap_passes_args(self):
         logger = object()
@@ -262,8 +289,9 @@ class TestFunctions(object):
         """
         # We need to do a bind such that we get an actual logger and not just
         # a lazy proxy.
-        l = wrap_logger(object(), processors=[]).new()
-        assert [] == l._processors
+        logger = wrap_logger(object(), processors=[]).new()
+
+        assert [] == logger._processors
 
     def test_wrap_returns_proxy(self):
         assert isinstance(wrap_logger(None), BoundLoggerLazyProxy)
