@@ -100,6 +100,32 @@ class TestConsoleRenderer(object):
             styles.kv_value + "bar" + styles.reset
         ) == rv
 
+    def test_init_accepts_overriding_levels(self, styles, padded):
+        """
+        Stdlib levels are rendered aligned, in brackets, and color coded.
+        """
+        my_styles = dev.ConsoleRenderer.get_default_level_styles(
+            colors=dev._has_colorama
+        )
+        my_styles["MY_OH_MY"] = my_styles["critical"]
+        cr = dev.ConsoleRenderer(
+            colors=dev._has_colorama, level_styles=my_styles
+        )
+
+        # this would blow up if the level_styles override failed
+        rv = cr(None, None, {
+            "event": "test", "level": "MY_OH_MY", "foo": "bar"
+        })
+
+        assert (
+            "[" + dev.RED + styles.bright +
+            dev._pad("MY_OH_MY", cr._longest_level) +
+            styles.reset + "] " +
+            padded +
+            styles.kv_key + "foo" + styles.reset + "=" +
+            styles.kv_value + "bar" + styles.reset
+        ) == rv
+
     def test_logger_name(self, cr, styles, padded):
         """
         Logger names are appended after the event.
@@ -228,6 +254,29 @@ class TestConsoleRenderer(object):
         assert dev._PlainStyles is plain_cr._styles
         assert "[info     ] event                          foo=bar" == rv
 
+    def test_colorama_force_colors(self, styles, padded):
+        """
+        If force_colors is True, use colors even if
+        the destination is non-tty.
+        """
+        cr = dev.ConsoleRenderer(
+            colors=dev._has_colorama, force_colors=dev._has_colorama)
+
+        rv = cr(None, None, {
+            "event": "test", "level": "critical", "foo": "bar"
+        })
+
+        assert (
+            "[" + dev.RED + styles.bright +
+            dev._pad("critical", cr._longest_level) +
+            styles.reset + "] " +
+            padded +
+            styles.kv_key + "foo" + styles.reset + "=" +
+            styles.kv_value + "bar" + styles.reset
+        ) == rv
+
+        assert not dev._has_colorama or dev._ColorfulStyles is cr._styles
+
     @pytest.mark.parametrize("rns", [True, False])
     def test_repr_native_str(self, rns):
         """
