@@ -4,32 +4,23 @@
 
 from __future__ import absolute_import, division, print_function
 
-import os
-
-import logging
 import collections
+import logging
 import logging.config
+import os
 
 import pytest
 
 from pretend import call_recorder
 
-from structlog import reset_defaults, configure, ReturnLogger, get_logger
+from structlog import ReturnLogger, configure, get_logger, reset_defaults
 from structlog.dev import ConsoleRenderer
-from structlog.processors import JSONRenderer
 from structlog.exceptions import DropEvent
+from structlog.processors import JSONRenderer
 from structlog.stdlib import (
-    BoundLogger,
-    CRITICAL,
-    LoggerFactory,
-    PositionalArgumentsFormatter,
-    ProcessorFormatter,
-    WARN,
-    _FixedFindCallerLogger,
-    add_log_level,
-    add_logger_name,
-    filter_by_level,
-    render_to_log_kwargs,
+    CRITICAL, WARN, BoundLogger, LoggerFactory, PositionalArgumentsFormatter,
+    ProcessorFormatter, _FixedFindCallerLogger, add_log_level, add_logger_name,
+    filter_by_level, render_to_log_kwargs
 )
 
 from .additional_frame import additional_frame
@@ -81,7 +72,7 @@ class TestLoggerFactory(object):
         name is not from structlog or one of the configurable other names.
         """
         assert '__main__' == additional_frame(LoggerFactory(
-            ignore_frame_names=['tests.', '_pytest.'])
+            ignore_frame_names=["tests.", "_pytest.", "pluggy"])
         ).name
 
     def test_deduces_correct_caller(self):
@@ -122,8 +113,9 @@ class TestLoggerFactory(object):
         If a positional argument is passed to the factory, it's used as the
         name instead of guessing.
         """
-        l = LoggerFactory()('foo')
-        assert 'foo' == l.name
+        lf = LoggerFactory()("foo")
+
+        assert "foo" == lf.name
 
 
 class TestFilterByLevel(object):
@@ -218,12 +210,22 @@ class TestBoundLogger(object):
         BoundLogger.exception sets exc_info=True.
         """
         bl = BoundLogger(ReturnLogger(), [], {})
-        assert ((),
-                {"exc_info": True, "event": "event"}) == bl.exception('event')
 
-    def test_exception_maps_to_error(self):
-        bl = BoundLogger(ReturnLogger(), [return_method_name], {})
-        assert "error" == bl.exception("event")
+        assert (
+            (),
+            {"exc_info": True, "event": "event"}
+        ) == bl.exception("event")
+
+    def test_exception_exc_info_override(self):
+        """
+        If *exc_info* is password to exception, it's used.
+        """
+        bl = BoundLogger(ReturnLogger(), [], {})
+
+        assert (
+            (),
+            {"exc_info": 42, "event": "event"}
+        ) == bl.exception("event", exc_info=42)
 
 
 class TestPositionalArgumentsFormatter(object):
@@ -594,7 +596,7 @@ class TestProcessorFormatter(object):
         )
         logger.handlers[0].setFormatter(formatter)
 
-        logging.getLogger().warn("have a stack trace", stack_info=True)
+        logging.getLogger().warning("have a stack trace", stack_info=True)
 
         out, err = capsys.readouterr()
         assert "" == out
